@@ -5,8 +5,8 @@ from ..const import CMD
 import re
 FALSE_ARR = ['', 'null', 'None', 'false', 'False','0']
 
-def all(region=None, osspath=None, locale=None, image=None, type=None, cluster=None, qsubuser=None, version=None, ssl=None, god=None):
-    if not region and not osspath and not locale and not image and not type and not cluster and not qsubuser and not version and not ssl and not god:
+def all(region=None, osspath=None, locale=None, image=None, type=None, cluster=None, qsubuser=None, vpc_cidr_block=None, version=None, ssl=None, god=None):
+    if not region and not osspath and not locale and not image and not type and not cluster and not qsubuser and not vpc_cidr_block and not version and not ssl and not god:
         show_config()
     else:
         if region:
@@ -27,6 +27,8 @@ def all(region=None, osspath=None, locale=None, image=None, type=None, cluster=N
             update_ssl(ssl)
         if qsubuser:
             update_qsubuser(qsubuser)
+        if vpc_cidr_block:
+            update_vpc_cidr_block(vpc_cidr_block)
         if god:
             update_god(god)
         print(green('done'))
@@ -48,6 +50,19 @@ def update_region(region):
         else:
             raise Exception(e)
 
+def update_vpc_cidr_block(vpc_cidr_block):
+    m = config.getConfigs(config.COMMON)
+
+    vpc_cidr_block = vpc_cidr_block.strip()
+    if vpc_cidr_block in FALSE_ARR:
+        config.removeConfig(config.COMMON, 'vpc_cidr_block')
+    else:
+        if re.match(r'^[0-9\.\/]+$', vpc_cidr_block):
+            m['vpc_cidr_block'] = vpc_cidr_block
+            config.setConfigs(config.COMMON, m)
+        else:
+            raise Exception('Invalid vpc_cidr_block format')
+
 
 def update_qsubuser(qsubuser):
     m = config.getConfigs(config.COMMON)
@@ -179,7 +194,7 @@ def update_god(god):
 def show_config():
     try:
         arr = ['region','accesskeyid','accesskeysecret','version','osspath','locale', 'defaultimage','defaulttype','defaultcluster','ssl','god',
-               'oss_region','oss_id','oss_key','qsubuser']
+               'oss_region','oss_id','oss_key','qsubuser','vpc_cidr_block']
         opt = config.getConfigs(config.COMMON, arr)
         if not opt:
             raise Exception('error')
