@@ -30,6 +30,7 @@ def submit(cmd=None, job_name=None, description=None, cluster=None, timeout=None
            nas_file_system=None,
            spot_price_limit=None,
             vpc_cidr_block = None,
+            vpc_id=None,
            show_json=False,show_dag=False):
 
     if cmd == None and file == None  or cmd!=None and cmd.startswith('-'):
@@ -83,7 +84,8 @@ def submit(cmd=None, job_name=None, description=None, cluster=None, timeout=None
         'nas_access_group': nas_access_group,
         'nas_file_system': nas_file_system,
 
-        'vpc_cidr_block': vpc_cidr_block,
+        'vpc_id': vpc_id,
+        'vpc_cidr_block': vpc_cidr_block if vpc_cidr_block else config.getConfigs(config.COMMON, ['vpc_cidr_block']).get('vpc_cidr_block'),
         'spot_price_limit': spot_price_limit
 
     }
@@ -93,6 +95,20 @@ def submit(cmd=None, job_name=None, description=None, cluster=None, timeout=None
 
     deal_with_pack(job_desc, show_json or show_dag)
 
+
+
+    tasks = job_desc['DAG']['Tasks']
+    for (taskName,task) in tasks.items():
+        if  task.get('AutoCluster') \
+                and task['AutoCluster'].get('Configs') \
+                and task['AutoCluster']['Configs'].get('Networks') \
+                and task['AutoCluster']['Configs']['Networks'].get('VPC') \
+                and task['AutoCluster']['Configs']['Networks']['VPC'].get('VpcId'):
+            if not task['AutoCluster']['Configs']['Networks']['VPC'].get('CidrBlock'):
+               raise Exception('vpc_id must works with vpc_cidr_block, taskName=%s' % taskName)
+
+
+
     if show_dag:
         # calc deps
         deps = util.get_task_deps(job_desc.get('DAG'))
@@ -277,6 +293,14 @@ def fix_by_opt(desc, opt, check_cluster):
                 if not task_desc['AutoCluster']['Configs']['Networks'].get('VPC'):
                     task_desc['AutoCluster']['Configs']['Networks']['VPC'] = {}
                 task_desc['AutoCluster']['Configs']['Networks']['VPC']['CidrBlock'] = opt.get('vpc_cidr_block')
+            if opt.get('vpc_id') :
+                if not task_desc['AutoCluster'].get('Configs'):
+                    task_desc['AutoCluster']['Configs'] = {}
+                if not task_desc['AutoCluster']['Configs'].get('Networks'):
+                    task_desc['AutoCluster']['Configs']['Networks'] = {}
+                if not task_desc['AutoCluster']['Configs']['Networks'].get('VPC'):
+                    task_desc['AutoCluster']['Configs']['Networks']['VPC'] = {}
+                task_desc['AutoCluster']['Configs']['Networks']['VPC']['VpcId'] = opt.get('vpc_id')
 
         # mounts
         if opt.get('no_cache_support'):
@@ -340,21 +364,22 @@ def extend_mount(desc, mount_m):
         desc['Mounts']['Entries'] = []
 
     # 去重
-    i = 0
+    m={}
     for n in desc['Mounts']['Entries']:
-        if mount_m.get(n['Source']):
-            del desc['Mounts']['Entries'][i]
-            i=i-1
-        i += 1
+        m[n['Source']]=n
 
-    ####################################################
-    for k,v in mount_m.items():
-        if k.startswith('oss://') or k.startswith('nas://'):
-            desc['Mounts']['Entries'].append({
+    for (k,v) in mount_m.items():
+        m[k]={
                 "Destination": v,
                 "Source": k,
                 "WriteSupport": k.endswith('/')
-            })
+            }
+    t=[]
+    for (k,v) in m.items():
+        t.append(v)
+
+    desc['Mounts']['Entries'] = t
+
 
 def trans_file_to_job_desc(file, check_cluster):
     cf = ConfigParser.ConfigParser()
@@ -550,6 +575,14 @@ def trans_file_to_job_desc(file, check_cluster):
                     task_desc['AutoCluster']['Configs']['Networks']['VPC'] = {}
                 task_desc['AutoCluster']['Configs']['Networks']['VPC']['CidrBlock'] = cf.get(sec, 'vpc_cidr_block')
 
+            if cf.has_option(sec, 'vpc_id'):
+                if not task_desc['AutoCluster'].get('Configs'):
+                    task_desc['AutoCluster']['Configs'] = {}
+                if not task_desc['AutoCluster']['Configs'].get('Networks'):
+                    task_desc['AutoCluster']['Configs']['Networks'] = {}
+                if not task_desc['AutoCluster']['Configs']['Networks'].get('VPC'):
+                    task_desc['AutoCluster']['Configs']['Networks']['VPC'] = {}
+                task_desc['AutoCluster']['Configs']['Networks']['VPC']['VpcId'] = cf.get(sec, 'vpc_id')
         # mounts
         if cf.has_option(sec, 'no_cache_support'):
             task_desc['Mounts']['CacheSupport'] = not cf.getboolean(sec, 'no_cache_support')
@@ -848,4 +881,5 @@ def gen_job_desc():
         "Type": "DAG",
         "Name": "cli-job",
         "Notification": {'Topic':{}}
-    }
\ No newline at end of file
+    }
+
