@@ -26,7 +26,10 @@ def getJSON():
                 'cluster': '''set default cluster, type '%s c' for more clsuter.''' % (CMD),
                 'version': "set version for stg environment, example: 2015-10-01",
                 "god": "use god mode, scope:[true|false]",
-                'ssl': 'requesting with https, scope:[true|false]'
+                'ssl': 'requesting with https, scope:[true|false]',
+                'qsubuser': 'set user for qsub, if unspecified, default:root',
+                'vpc_cidr_block': '''specify CIDR IP block for VPC, usually: 192.168.0.0/16,
+                                       if you don't specify or it is set to false, then use the classic network'''
             }
         },
         'info': {
@@ -43,6 +46,13 @@ def getJSON():
                  'show_json': 'show json'
              }
         },
+        "app": {
+            "description": 'show available apps.',
+            "option": {
+                "public": 'get public Apps, it works only if you are getting App detail',
+                "description": "show json only"
+            }
+        },
         "disk_type": {
             "description": 'show available disk types.',
              'option': {
@@ -142,10 +152,11 @@ def getJSON():
                                              and it is always using with nas_access_group and nas_file_system.
                                              example2: oss://path/to/mount/:/home/admin/dir/,
                                              and file is also supported: oss://path/to/mount/a.txt:/home/admin/dir/a.txt.""",
-                'nas_access_group': 'NAS access groups',
-                'nas_file_system': 'NAS file system',
+                'nas_access_group': 'NAS access groups, multiple items should be separated by comma',
+                'nas_file_system': 'NAS file system, multiple items should be separated by comma',
                 'no_cache_support': 'optional, cancel the cache for ossmounter',
                 'vpc_cidr_block': 'CIDR, such as: 192.168.0.0/16',
+                'vpc_id': 'set VPC id',
                 'show_json': 'optional, just output cluster json, won\'t create a cluster, default: false',
                 'filePath': 'submit with a cluster description json file, other options are invalid'
             }
@@ -164,14 +175,93 @@ def getJSON():
                 'env': "optional,set environment variables, format: <k>:<v>[,<k2>:<v2>...]",
                 'user_data': "optional, user data k-v pairs, exp: a:b,c:e",
                 'spot_price_limit': 'optional, it\'s available when resource_type is Spot(unit: yuan,works to three decimal places). Set to 0 means using the system automatically bid(But lower than the "OnDemand" price)',
-                'mount': """optional,mount a nas path to local file system in read/write mode, kv-pairs, multi-supported,
-        format: <nas_path>:<dir_path>[,<nas_path2>:<dir_path2>...],
-        example: nas://path/to/mount:/home/admin/dir.
-        and it is always using with nas_access_group and nas_file_system""",
+                'mount': """optional,mount nas path to local file system in read/write mode,
+                                             or mount oss path to local file system in read mode.
+                                             format: <nas_path|oss_path>:<dir_path>[,<nas_path2|oss_path2>:<dir_path2>...],
+                                             example: nas://path/to/mount/:/home/admin/dir/.
+                                             and it is always using with nas_access_group and nas_file_system.
+                                             example2: oss://path/to/mount/:/home/admin/dir/,
+                                             and file is also supported: oss://path/to/mount/a.txt:/home/admin/dir/a.txt.""",
                 'image': "optional, imageId, type '%s t' for more" % CMD,
                 'show_json': 'optional, just output cluster json, won\'t create a cluster, default: false'
             }
         },
+        "create_app": {
+            'description': 'create App',
+            "option": {
+                'file': 'optional, create an app with app description json file',
+                'env': "optional,set environment variables, format: <k>:<v>[,<k2>:<v2>...]",
+                'docker': """optional,optional, use docker, format: <docker_image_name>@<docker_storage_oss_path>,
+                                          example: localhost:5000/myubuntu@oss://bucket/dockers/
+                                          or for short: myubuntu@oss://bucket/dockers/ """,
+                'image': "optional, imageId, type '%s t' for more" % CMD,
+
+
+                'type': "optional, instanceType, type '%s t' for more , format:  {defaultValue}:{overwritable}:{desc}" % (CMD),
+                'resource_type': 'optional, default: "OnDemand", scope:[OnDemand|Spot] , format: {defaultValue}:{overwritable}:{desc}',
+                'nodes': "optional, instance counts, format:  {defaultValue}:{overwritable}:{desc}",
+                'disk_type': '''optional, system disk type(type '%s d' for more), format: {defaultValue}:{overwritable}:{desc}''' % CMD,
+                'min_disk_size': 'optional, System disk minimum limit, unit: GB, format: {defaultValue}:{overwritable}:{desc}',
+                'max_retry_count': 'optional, After an Instance failed, the maximum number of retries, format: {defaultValue}:{overwritable}:{desc}',
+                'timeout': "optional,job would failed if it had expired, default: 86400(1 days).format: {defaultValue}:{overwritable}:{desc}",
+
+                'inputs': '''optional, input parameters, format: item1,item2..,
+                                          eash item format: {name}[:{type}][:{localpath}][:{desc}][:{defaultValue}]''',
+                'outputs': '''optional, outout parameters, format: item1,item2..,
+                                          eash item format: {name}[:{type}][:{localpath}][:{desc}]''',
+
+                'daemonize': 'When the application is executed, whether to restart each time. default：false',
+                'description': 'optional, description of the App',
+
+                'show_json': 'optional, just output App json, won\'t create an App, default: false'
+            }
+        },
+        "update_app": {
+            'description': 'update App. ',
+            "option": {
+                'env': "optional,set environment variables, format: <k>:<v>[,<k2>:<v2>...]",
+                'docker': """optional,optional, use docker, format: <docker_image_name>@<docker_storage_oss_path>,
+                                      example: localhost:5000/myubuntu@oss://bucket/dockers/
+                                      or for short: myubuntu@oss://bucket/dockers/ """,
+                'image': "optional, imageId, type '%s t' for more" % CMD,
+
+                'daemonize': 'When the application is executed, whether to restart each time. default：false',
+                'description': 'optional, description of the App',
+                'yes': "optional, update in silent mode",
+
+                'show_json': 'optional, just output App json, won\'t create an App, default: false'
+            }
+        },
+        'delete_app': {
+           'description': 'Delete App',
+            'option': {
+                'yes': 'optional, delete apps in silent mode'
+            }
+        },
+        "asub": {
+            'description': 'submit an App job',
+            "option": {
+                'type': "optional, instanceType, type '%s t' for more" % ( CMD),
+                'resource_type': 'optional, default: "OnDemand", scope:[OnDemand|Spot]',
+                'nodes': "optional, instance counts",
+                'disk_type': '''optional, system disk type(type '%s d' for more)''' % CMD,
+                'min_disk_size': 'optional, System disk minimum limit, unit: GB ',
+                'max_retry_count': 'optional, After an Instance failed, the maximum number of retries ',
+                'timeout': "optional, job would failed if it had expired, default: 86400(1 days) ",
+                'description': 'optional, description for the job',
+                'config': 'optional, k-v pairs in config, format: k=v[,k2=v2][,k3=v3]...',
+                'show_json': '''optional, just output the json, won\'t create a job, default: false\n''',
+                'param_desc': '''**********************************************
+        These options bellow are special parameters of this App
+        Input parameter starts with --input_, and you can change to --input_from_file_ if necessary.
+        Ouput parameter starts with --output_.
+        **********************************************
+                    ''',
+                'inputs': '''If suffix is //:oss, it will generate oss path automaticly,
+                                 and file will be upload to oss automaticly to, such as: --iWDL hello.wdl//:oss''',
+                'outputs': '''If suffix is //:oss, it will generate oss path automaticly, such as: --iWDL ./demo///:oss'''
+            }
+        },
         'create_job': {
             'description': 'create job from description json or a json file path.',
             'option': {
@@ -262,13 +352,14 @@ def getJSON():
                 'notification_events': "Events for notification, type '%s e' for more." % CMD,
                 'notification_topic': "Topic name in MNS.",
                 'notification_endpoint': "MNS Endpoint, see in MNS web console.",
-                'nas_access_group': 'NAS access groups',
-                'nas_file_system': 'NAS file system',
+                'nas_access_group': 'NAS access groups, multiple items should be separated by comma',
+                'nas_file_system': 'NAS file system, multiple items should be separated by comma',
                 'resource_type': 'optional, default "OnDemand", scope: [OnDemand|Spot]',
                 'spot_price_limit': 'optional, it\'s available when resource_type is Spot(unit: yuan,works to three decimal places). Set to 0 means using the system automatically bid(But lower than the "OnDemand" price)',
                 'reserve_on_fail': 'optional, won\'t release auto-cluster when job failed',
                 'no_cache_support': 'optional, cancel the cache for ossmounter',
                 'vpc_cidr_block': 'CIDR, such as: 192.168.0.0/16',
+                'vpc_id': 'set VPC id',
                 'show_json': 'optional,just output job.json, won\'t submit a job, default: false',
                 'show_dag': 'optional,just output dag graph, won\'t submit a job, default: false'
             }
@@ -281,7 +372,7 @@ def getJSON():
             'create': {
                 'description': 'create a job project',
                 'option': {
-                    'type': """optional, job project type, default: empty(python), scope: [empty|python|java|shell]""",
+                    'type': """optional, job project type, default: empty(python), scope: [empty|python|java|shell|wdl]""",
                     'job': 'optional, create job project from an exists job_id'
                 }
             },
@@ -372,7 +463,7 @@ def getJSON():
             }
         },
         'qsub': {
-            'description': '%sqsub supported. Now migrate you qsub command to BatchCompute is much easier than you think' % (magenta('(New)')),
+            'description': 'qsub supported. Now migrate you qsub command to BatchCompute is much easier than you think',
             'detail': 'qsub supported. Now migrate you qsub command to BatchCompute is much easier than you think',
             'option': {
                 'd': '''Defines the working directory path to be used for the job. If the -d option is not specified,
@@ -406,8 +497,7 @@ def getJSON():
             }
         },
         'qstat': {
-            'description': '%sshow status of pbs batch jobs' % (
-            magenta('(New)')),
+            'description': 'show status of pbs batch jobs',
             'option': {
                 'f': '''Specifies that a full status display be written to standard out.''',
                 'a': '''"All" jobs are displayed in the alternative format, see the Standard Output section.
@@ -424,17 +514,21 @@ def getJSON():
             }
         },
         'qdel': {
-            'description': '%sDelete job' % (
-                magenta('(New)')),
+            'description': 'Delete job',
             'option': {
                 'W': '''Unsupported'''
             }
         },
         'qhost': {
-            'description': '%sUnsupported' % (
-                magenta('(New)')),
+            'description': 'Unsupported',
             'option': {
 
             }
+        },
+        'template_gen': {
+            'description': 'Init a native job project using template',
+            'option': {
+                'type': 'required, generate with specify template, scope: [gatk|wdl]'
+            }
         }
     }
