@@ -46,6 +46,7 @@ def __get_json():
                 'god': "使用上帝模式, 可选范围:[true|false]",
                 'ssl': '使用https访问BatchCompute, 可选范围:[true|false]',
                 'qsubuser': '设置qsub用户名, 如果不设置,默认:root',
+                'vpc_cidr_block': '设置默认使用VPC的CIDR IP段, 一般设置为: 192.168.0.0/16, 如果不设置或者设置为false, 则使用经典网络',
             }
         },
         'info': {
@@ -170,6 +171,7 @@ def __get_json():
                 'nas_file_system': 'NAS 文件系统',
                 'no_cache_support': '可选, 取消OSSMounter缓存',
                 'vpc_cidr_block': 'IP网段,如: 192.168.0.0/16',
+                'vpc_id': '设置 VPC id',
                 'show_json': '只显示cluster json不创建',
                 'filePath': '通过集群描述json文件提交,其他options将失效'
             }
@@ -359,6 +361,7 @@ def __get_json():
                 'reserve_on_fail': '可选, 作业失败不会释放autoCluster, 便于调查问题',
                 'no_cache_support': '可选, 取消OSSMounter缓存',
                 'vpc_cidr_block': 'IP网段,如: 192.168.0.0/16',
+                'vpc_id': '设置 VPC id',
                 'show_json': '只显示json不提交作业',
                 'show_dag': '只显示DAG图不提交作业'
             }
