@@ -2,7 +2,7 @@ import json
 import os
 from terminal import white
 from . import config
-
+import re
 usr_home = os.path.expanduser('~')
 cfg_dir = os.path.join(usr_home, '.batchcompute')
 
@@ -42,7 +42,8 @@ def get_index(index, title):
 
 
 def get(id, title, needCheckGod=False):
-    if needCheckGod and not config.isGod() and '-' not in id:
+
+    if needCheckGod and not config.isGod() and re.match(r'^[0-9]+$', id):
         raise Exception('Invalid id: %s' % id)
 
     try:
